import { csv, select,legendColor } from 'd3';
import { scatterPlot } from './scatterPlot';

// Import and parse the data
const csvUrl = [
  'https://gist.githubusercontent.com/',
  'Platoch/', 
  '67fdb69375a898cb864792cfefeb01f4/', 
  'raw/6cdc57283eb3bf9b658a011d3df117bb6a6a3191/', 
  'Iris.csv', 
].join('');
const parseRow = (d) => {
  d.SepalLength = +d.SepalLength;
  d.SepalWidth = +d.SepalWidth;
  d.PetalLength = +d.PetalLength;
  d.PetalWidth = +d.PetalWidth;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const xValue = (d) => d.SepalLength;
const yValue = (d) => d.PetalWidth;
const rxValue = (d) => d.PetalLength;
const ryValue = (d) => d.SepalWidth;
const speciesValue = (d) => d.Species;
const colorValue = d => d.Species;
const colorLabel = '';


const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.PetalWidth);
  const y = yValue((d) => d.PetalLength);
  
//   Set the colors of different categories
  const markColors = (d) => {
        	switch(d){
            case 'Iris-virginica':
              return 'orange';
            case 'Iris-versicolor':
              return 'blue';
            default:
              return 'green';
          }
        }
  
  const marks = data.map((d) => ({
          x: xValue((d) => d.PetalWidth),
          y: yValue((d) => d.PetalLength),
          species: speciesValue(d),
          color: markColors(speciesValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
  
  
//Defining scatterplot structure from the imported scatterPlot object
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.PetalWidth)
    .yValue((d) => d.PetalLength)
    .margin({
      top: 35,
      right: 50,
      bottom: 80,
      left: 95,

    })
    .radius(5);
  
  
 const g = svg.append('g')
          .attr('transform', `translate(${100},${100})`);

      const colorLegendG = g.append('g')
          .attr('transform', `translate(${100}, 150)`);





//Defining the shape and structure of data points  
svg
          .selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));

// Columns to plot. Since PetalLength is fixed on y axis, we do not include it
//   because it will only result in a straight line.
  
  const columns = [
    'PetalWidth',
    'SepalWidth',
    'SepalLength',
  ];

//   Iterating in columns and plotting each element of colors against PetalLength
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
		svg.selectAll('text').remove();
    svg.call(plot);


   
// Set figure's title
svg.append("text").attr("x", 450)
  .attr("y", 20).text("Iris Data")
  .style("font-size", "25px")
  .attr("alignment-baseline","middle")
  
// Label the y Axis
    svg
        	.append("text")
        	.attr('transform', 'rotate(-90)')
        	.attr('x',0 - (height /2))
        	.attr("y",  height/12)
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
        	.text("Petal Length");
    
// Adding legend points
    svg.append("circle")
       .attr("cx",830)
       .attr("cy",290)
       .attr("r", 6)
       .style("fill", "green")
		svg.append("circle")
       .attr("cx",830)
       .attr("cy",320)
       .attr("r", 6)
       .style("fill", "blue")
		svg.append("circle")
       .attr("cx",830)
       .attr("cy",350)
       .attr("r", 6)
       .style("fill", "orange")
    
// Labelling the legend points
    
svg.append("text")
  .attr("x", 850)
  .attr("y", 290)
  .text("Setosa")
  .style("font-size", "20px")
  .attr("alignment-baseline","middle")
    
svg.append("text")
  .attr("x", 850)
  .attr("y", 320)
  .text("Versicolor")
  .style("font-size", "20px")
  .attr("alignment-baseline","middle")
    
svg.append("text")
  .attr("x", 850)
  .attr("y", 350)
  .text("Virginica")
  .style("font-size", "20px")
  .attr("alignment-baseline","middle")

    
// Plot PetalWidth on x-axis
    if(i % columns.length==0) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("Petal Width");
// Plot SepalWidth on x-axis
    else if(i % columns.length==1) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("Sepal Width");
    
     // Plot SepalLength on x-axis
       else 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("Sepal Length");
    i++;
  }, 2300);// 
};
main();



